Struct rustlearn::array::dense::Array [] [src]

pub struct Array {
    // some fields omitted
}

Basic two-dimensional dense matrix type.

Methods

impl Array
[src]

Create a rows by cols array of zeros.

Create a rows by cols array of ones.

Change the shape of the array to rows by cols.

Panics

If the number of elements implied by the new shape is different from the current number of elements.

Return the order (row-major or column-major) of the array.

Return an immutable reference to the underlying data buffer of the array.

The arrangement of the elements in that vector is dependent on whether this is a row-major or a column-major array.

Return an immutable reference to the underlying data buffer of the array.

The arrangement of the elements in that vector is dependent on whether this is a row-major or a column-major array.

Return an mutable reference to the underlying data buffer of the array.

The arrangement of the elements in that vector is dependent on whether this is a row-major or a column-major array.

Transpose the matrix.

Compute the sum of the entries of the array.

Compute the mean of the array.